
#include <windows.h>  
#include "getbkcol.h"  


#if defined (WIN32)
	#define IS_WIN32 TRUE
#else
	#define IS_WIN32 FALSE
#endif

#define IS_NT      IS_WIN32 && (BOOL)(GetVersion() < 0x80000000)
#define IS_WIN32S  IS_WIN32 && (BOOL)(!(IS_NT) && (LOBYTE(LOWORD(GetVersion()))<4))
#define IS_WIN95   (BOOL)(!(IS_NT) && !(IS_WIN32S)) && IS_WIN32

HINSTANCE hInst;   // current instance

LPCTSTR lpszAppName = "MyApp";
LPCTSTR lpszTitle   = "GetBkColor()"; 


BOOL RegisterWin95( CONST WNDCLASS* lpwc );


int APIENTRY WinMain( HINSTANCE hInstance, HINSTANCE hPrevInstance,
                      LPTSTR lpCmdLine, int nCmdShow)
{
   MSG      msg;
   HWND     hWnd; 
   WNDCLASS wc;

   wc.style         = CS_HREDRAW | CS_VREDRAW | CS_OWNDC;
   wc.lpfnWndProc   = (WNDPROC)WndProc;       
   wc.cbClsExtra    = 0;                      
   wc.cbWndExtra    = 0;                      
   wc.hInstance     = hInstance;              
   wc.hIcon         = LoadIcon (hInstance, lpszAppName); 
   wc.hCursor       = LoadCursor(NULL, IDC_ARROW);
   wc.hbrBackground = (HBRUSH)(COLOR_WINDOW+1);
   wc.lpszMenuName  = lpszAppName;              
   wc.lpszClassName = lpszAppName;              

   if ( IS_WIN95 )
   {
      if ( !RegisterWin95( &wc ) )
         return( FALSE );
   }
   else if ( !RegisterClass( &wc ) )
      return( FALSE );

   hInst = hInstance; 

   hWnd = CreateWindow( lpszAppName, 
                        lpszTitle,    
                        WS_OVERLAPPEDWINDOW, 
                        CW_USEDEFAULT, 0, 
                        CW_USEDEFAULT, 0,  
                        NULL,              
                        NULL,              
                        hInstance,         
                        NULL               
                      );

   if ( !hWnd ) 
      return( FALSE );

   ShowWindow( hWnd, nCmdShow ); 
   UpdateWindow( hWnd );         

   while( GetMessage( &msg, NULL, 0, 0) )   
   {
      TranslateMessage( &msg ); 
      DispatchMessage( &msg );  
   }

   return( msg.wParam ); 
}


BOOL RegisterWin95( CONST WNDCLASS* lpwc )
{
   WNDCLASSEX wcex;

   wcex.style         = lpwc->style;
   wcex.lpfnWndProc   = lpwc->lpfnWndProc;
   wcex.cbClsExtra    = lpwc->cbClsExtra;
   wcex.cbWndExtra    = lpwc->cbWndExtra;
   wcex.hInstance     = lpwc->hInstance;
   wcex.hIcon         = lpwc->hIcon;
   wcex.hCursor       = lpwc->hCursor;
   wcex.hbrBackground = lpwc->hbrBackground;
   wcex.lpszMenuName  = lpwc->lpszMenuName;
   wcex.lpszClassName = lpwc->lpszClassName;

   // Added elements for Windows 95.
   //...............................
   wcex.cbSize = sizeof(WNDCLASSEX);
   wcex.hIconSm = LoadIcon(wcex.hInstance, "SMALL");
			
   return RegisterClassEx( &wcex );
}


LRESULT CALLBACK WndProc( HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam )
{
   switch( uMsg )
   {
      case WM_PAINT :
              {
                 PAINTSTRUCT ps;

                 BeginPaint( hWnd, &ps );

                 TextOut( ps.hdc, 10, 10, "Sample Text", 11 );

                 EndPaint( hWnd, &ps );
              }
              break;

      case WM_INITMENU :
              {
                 HDC hDC = GetDC( hWnd );

                 if ( GetBkColor( hDC ) == RGB( 255, 255, 255 ) )
                    CheckMenuRadioItem( (HMENU)wParam, IDM_WHITE, IDM_BLACK, 
                                                       IDM_WHITE, MF_BYCOMMAND );
                 else if ( GetBkColor( hDC ) == RGB( 192, 192, 192 ) )
                    CheckMenuRadioItem( (HMENU)wParam, IDM_WHITE, IDM_BLACK, 
                                                       IDM_GRAY, MF_BYCOMMAND );
                 else if ( GetBkColor( hDC ) == RGB( 0, 0, 0 ) )
                    CheckMenuRadioItem( (HMENU)wParam, IDM_WHITE, IDM_BLACK, 
                                                       IDM_BLACK, MF_BYCOMMAND );

                 if ( GetBkMode( hDC ) == OPAQUE )
                    CheckMenuRadioItem( (HMENU)wParam, IDM_OPAQUE, IDM_TRANSPARENT, 
                                                       IDM_OPAQUE, MF_BYCOMMAND );
                 else
                    CheckMenuRadioItem( (HMENU)wParam, IDM_OPAQUE, IDM_TRANSPARENT, 
                                                       IDM_TRANSPARENT, MF_BYCOMMAND );
                 ReleaseDC( hWnd, hDC );
              }
              break;

      case WM_COMMAND :
              switch( LOWORD( wParam ) )
              {
                 case IDM_WHITE :
                 case IDM_GRAY :
                 case IDM_BLACK :
                 case IDM_OPAQUE :
                 case IDM_TRANSPARENT :
                    {
                       HDC hDC = GetDC( hWnd ); 

                       switch( LOWORD( wParam ) )
                       {                          
                          case IDM_WHITE : SetBkColor( hDC, RGB( 255, 255, 255 ) ); break;
                          case IDM_GRAY  : SetBkColor( hDC, RGB( 192, 192, 192 ) ); break;
                          case IDM_BLACK : SetBkColor( hDC, RGB( 0, 0, 0 ) );       break;

                          case IDM_OPAQUE      : SetBkMode( hDC, OPAQUE );      break;
                          case IDM_TRANSPARENT : SetBkMode( hDC, TRANSPARENT ); break;
                       }

                       ReleaseDC( hWnd, hDC );
                       InvalidateRect( hWnd, NULL, TRUE );
                    }
                    break;
                        
                 case IDM_ABOUT :
                        DialogBox( hInst, "AboutBox", hWnd, (DLGPROC)About );
                        break;

                 case IDM_EXIT :
                        DestroyWindow( hWnd );
                        break;
              }
              break;
      
      case WM_DESTROY :
              PostQuitMessage(0);
              break;

      default :
            return( DefWindowProc( hWnd, uMsg, wParam, lParam ) );
   }

   return( 0L );
}


LRESULT CALLBACK About( HWND hDlg,           
                        UINT message,        
                        WPARAM wParam,       
                        LPARAM lParam)
{
   switch (message) 
   {
       case WM_INITDIALOG: 
               return (TRUE);

       case WM_COMMAND:                              
               if (   LOWORD(wParam) == IDOK         
                   || LOWORD(wParam) == IDCANCEL)    
               {
                       EndDialog(hDlg, TRUE);        
                       return (TRUE);
               }
               break;
   }

   return (FALSE); 
}
